==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/editace/view_podle_kalendare.php <==
<?php
/**
 * stanislav.elbl, 10.10.2014
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\RonPortalSettings;

/** @var $this PodleKalendareFormular  */

?>
<h1><?= TextManager::_('Generovani_podle_kalendare') ?></h1>

<?php MessageManager::getInstance() ->showMessages(); ?>

<form enctype="multipart/form-data" method="post" action="?menuid=podlekalendare&idpp=<?= $this->pp->idPP ?>&obdobi=<?= DateUtils::dateToUrlString($this -> obdobi -> zacatek) ?>">
    <input type="hidden" name="action" value="vlozpodlekalendare" />
    <input type="hidden" name="idpp" value="<?= $this -> pp -> idPP ?>" />
    <input type="hidden" name="obdobi" value="<?= $this -> obdobi -> zacatek ?>" />

    <div class="form form-sm middle-form" id="dochazkapodlekalendare">
        <div class="form-content">
            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-7"><strong><?= StringUtils::htmlTextConvert($this ->obdobi ->popis) ?></strong></div>
                <div class="col col-2 d-xs-none formFotoContainer">
                    <!-- foto -->
                    <?php if ($this ->pp ->idFotografie) { ?>
                        <div class="formFoto">
                            <img src="?menuid=editace&action=foto&idpp=<?= $this ->pp ->idPP ?>">
                        </div>
                    <?php } ?>
                </div>
            </div>

            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-7"><strong><?= $this -> pp -> jmenoPrijmeni ?></strong></div>
            </div>

            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-7"><?= TextManager::_('Datum_posledniho_zpracovani') . "&nbsp;" . date('j.n.Y', $this -> datumZpracovaniDochazky ) ?></div>
            </div>

            <div class="row margin-top"></div>

            <div class="row" id="podlekalendare_row_datum">
                <div class="col col-6 col-sm-3 caption">
                    <label for="podle_kalendare_DatumOd"><?= TextManager::_('Datum_od') ?></label>
                </div>
                <div class="col col-6 col-sm-3">
                    <input type='text' id="podle_kalendare_DatumOd" size='10' maxlength='10' name='DatumOd' <?= MessageManager::getClassHtml('DatumOd')?>
                           value='<?= StringUtils::htmlTextConvert($this -> datumOdStr) ?>'  data-roncalendar-next="DatumDo" />
                    <i class="showcalendar inline-glyph glyph-button fa glyph-calendar" data-roncalendar-inputname="DatumOd"></i>
                </div>
                <div class="col col-6 col-sm-1 caption">
                    <label for="podle_kalendare_DatumDo"><?= TextManager::_('Do') ?></label>
                </div>
                <div class="col col-6 col-sm-3">
                    <input type='text' id="podle_kalendare_DatumDo" size='10' maxlength='10' name='DatumDo' <?= MessageManager::getClassHtml('DatumDo')?>
                           value='<?= StringUtils::htmlTextConvert($this -> datumDoStr) ?>'  data-roncalendar-prev="DatumOd" />
                    <i class="showcalendar inline-glyph glyph-button fa glyph-calendar" data-roncalendar-inputname="DatumDo"></i>
                </div>
            </div>

            <div class="row" id="podlekalendare_row_operace">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Operace') ?></div>
                <div class="col col-8 col-sm-6"><?php $this ->renderVyberOperace(true); ?></div>
                <div class="col col-4 col-sm-3"><?php $this ->renderVyberOperace(false); ?></div>
            </div>

            <?php
            // pripadne jeste stredisko (rozdeleni)
            if (RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI)) { ?>
                <div class="row" id="podlekalendare_row_rozdeleni">
                    <div class="col col-12 col-sm-3 caption"><?= RonPortalSettings::getValue(RonPortalSettings::EDITACE_NADPIS_ROZDELENI) ?: TextManager::_('Rozdeleni') ?></div>
                    <div class="col col-8 col-sm-6"><?php $this ->renderVyberRozdeleni(true); ?></div>
                    <div class="col col-4 col-sm-3"><?php $this ->renderVyberRozdeleni(false); ?></div>
                </div>
            <?php } ?>

            <div class="row" id="podlekalendare_row_delka">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Delka') ?></div>
                <div class="col col-12 col-sm-9">
                    <label>
                        <input name="delka" type="radio" value="0" <?= (!$this -> delka) ? 'checked="checked"' : '' ?> />
                        <?= TextManager::_('Absence_cela_smena') ?>
                    </label>

                    <label>
                        <input name="delka" type="radio" value="1" <?= ($this -> delka === 1) ? 'checked="checked"' : '' ?> />
                        <?= TextManager::_('Absence_pulka_smeny1') ?>
                    </label>

                    <label>
                        <input name="delka" type="radio" value="2" <?= ($this -> delka === 2) ? 'checked="checked"' : '' ?> />
                        <?= TextManager::_('Absence_pulka_smeny2') ?>
                    </label>
                </div>
            </div>

            <div class="row margin-top" id="podlekalendare_row_pocatekkonec">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-9">
                    <label>
                        <input name="pocatekkonec" class="app_check" type="checkbox" value="1" <?= $this -> pouzitPocatek ? 'checked="checked"' : '' ?> />
                        <span class="<?= $this -> pouzitPocatek ? 'checkbox_text_checked' : 'checkbox_text_unchecked' ?>"><?= TextManager::_('Pouzit_pocatek_konec_smeny') ?></span>
                    </label>
                </div>
            </div>

            <div class="row" id="podlekalendare_row_pevnejadro">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-9">
                    <label>
                        <input name="pevnejadro" class="app_check" type="checkbox" value="1" <?= $this -> pevneJadro ? 'checked="checked"' : '' ?> />
                        <span class="<?= $this -> pevneJadro ? 'checkbox_text_checked' : 'checkbox_text_unchecked' ?>"><?= TextManager::_('Pouzit_pevne_jadro') ?></span>
                    </label>
                </div>
            </div>

            <div class="row" id="podlekalendare_row_autoopakovat">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-9">
                    <label>
                        <input name="autoopakovat" class="app_check" type="checkbox" value="1" <?= $this -> automatickyOpakovat ? 'checked="checked"' : '' ?> />
                        <span class="<?= $this -> automatickyOpakovat ? 'checkbox_text_checked' : 'checkbox_text_unchecked' ?>"><?= TextManager::_('Automaticky_opakovat') ?></span>
                    </label>
                </div>
            </div>

            <?php if ( !RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_VKLADAT_PRESTAVKY) ) { ?>
                <div class="row" id="podlekalendare_row_vlozitprestavky">
                    <div class="col col-3 d-xs-none"></div>
                    <div class="col col-12 col-sm-9">
                        <label>
                            <input name="vlozitprestavky" class="app_check" type="checkbox" value="1" <?= $this -> vlozitPrestavky ? 'checked="checked"' : '' ?> />
                            <span class="<?= $this -> vlozitPrestavky ? 'checkbox_text_checked' : 'checkbox_text_unchecked' ?>"><?= TextManager::_('Vlozit_prestavky') ?></span>
                        </label>
                    </div>
                </div>
            <?php } ?>
        </div>

        <div class="buttons row">
            <div class="col col-3">
                <span><a href="?menuid=zpracovanadochazka&osoba=<?= $this ->pp ->idPP ?>&obdobi=<?= DateUtils::dateToUrlString($this ->obdobi ->zacatek) ?>"><?= TextManager::_('Zpet') ?></a></span>
            </div>
            <div class="col col-9">
                <input type="submit" class="submitbutton" name="podlepuvodni" value="<?= TextManager::_('form.Insert') ?>" />
            </div>

        </div>
    </div>
</form>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/editace/view_podle_kalendare.php <==
<?php
/**
 * stanislav.elbl, 10.10.2014
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\RonPortalSettings;

/** @var $this PodleKalendareFormular  */

$popisT = TextManager::_('db_obdobi_popis_' . date('n', $this ->obdobi ->zacatek), '');

?>
<h1><?= TextManager::_('Generovani_podle_kalendare') ?></h1>

<?php MessageManager::getInstance() ->showMessages(); ?>

<form enctype="multipart/form-data" method="post" action="?menuid=podlekalendare&idpp=<?= $this->pp->idPP ?>&obdobi=<?= DateUtils::dateToUrlString($this -> obdobi -> zacatek) ?>">
    <input type="hidden" name="action" value="vlozpodlekalendare" />
    <input type="hidden" name="idpp" value="<?= $this -> pp -> idPP ?>" />
    <input type="hidden" name="obdobi" value="<?= $this -> obdobi -> zacatek ?>" />

    <div class="form form-sm middle-form" id="dochazkapodlekalendare">
        <div class="form-content">
            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-7"><strong><?=
                        StringUtils::htmlTextConvert($popisT
                            ? sprintf($popisT, date('Y', $this ->obdobi ->zacatek))
                            : TextManager::_($this ->obdobi ->popis))
                        ?></strong></div>
                <div class="col col-2 d-xs-none formFotoContainer">
                    <!-- foto -->
                    <?php if ($this ->pp ->idFotografie) { ?>
                        <div class="formFoto">
                            <img src="?menuid=editace&action=foto&idpp=<?= $this ->pp ->idPP ?>">
                        </div>
                    <?php } ?>
                </div>
            </div>

            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-7"><strong><?= $this -> pp -> jmenoPrijmeni ?></strong></div>
            </div>

            <div class="row">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-7"><?= TextManager::_('Datum_posledniho_zpracovani') . "&nbsp;" . date('j.n.Y', $this -> datumZpracovaniDochazky ) ?></div>
            </div>

            <div class="row margin-top"></div>

            <div class="row" id="podlekalendare_row_datum">
                <div class="col col-6 col-sm-3 caption">
                    <label for="podle_kalendare_DatumOd"><?= TextManager::_('Datum_od') ?></label>
                </div>
                <div class="col col-6 col-sm-3">
                    <input type='text' id="podle_kalendare_DatumOd" size='10' maxlength='10' name='DatumOd' <?= MessageManager::getClassHtml('DatumOd')?>
                           value='<?= StringUtils::htmlTextConvert($this -> datumOdStr) ?>'  data-roncalendar-next="DatumDo" />
                    <i class="showcalendar inline-glyph glyph-button fa glyph-calendar" data-roncalendar-inputname="DatumOd"></i>
                </div>
                <div class="col col-6 col-sm-1 caption">
                    <label for="podle_kalendare_DatumDo"><?= TextManager::_('Do') ?></label>
                </div>
                <div class="col col-6 col-sm-3">
                    <input type='text' id="podle_kalendare_DatumDo" size='10' maxlength='10' name='DatumDo' <?= MessageManager::getClassHtml('DatumDo')?>
                           value='<?= StringUtils::htmlTextConvert($this -> datumDoStr) ?>'  data-roncalendar-prev="DatumOd" />
                    <i class="showcalendar inline-glyph glyph-button fa glyph-calendar" data-roncalendar-inputname="DatumDo"></i>
                </div>
            </div>

            <div class="row" id="podlekalendare_row_operace">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Operace') ?></div>
                <div class="col col-8 col-sm-6"><?php $this ->renderVyberOperace(true); ?></div>
                <div class="col col-4 col-sm-3"><?php $this ->renderVyberOperace(false); ?></div>
            </div>

            <?php
            // pripadne jeste stredisko (rozdeleni)
            if (RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI)) { ?>
                <div class="row" id="podlekalendare_row_rozdeleni">
                    <div class="col col-12 col-sm-3 caption"><?= RonPortalSettings::getValue(RonPortalSettings::EDITACE_NADPIS_ROZDELENI) ?: TextManager::_('Rozdeleni') ?></div>
                    <div class="col col-8 col-sm-6"><?php $this ->renderVyberRozdeleni(true); ?></div>
                    <div class="col col-4 col-sm-3"><?php $this ->renderVyberRozdeleni(false); ?></div>
                </div>
            <?php } ?>

            <div class="row" id="podlekalendare_row_delka">
                <div class="col col-12 col-sm-3 caption"><?= TextManager::_('Delka') ?></div>
                <div class="col col-12 col-sm-9">
                    <label>
                        <input name="delka" type="radio" value="0" <?= (!$this -> delka) ? 'checked="checked"' : '' ?> />
                        <?= TextManager::_('Absence_cela_smena') ?>
                    </label>

                    <label>
                        <input name="delka" type="radio" value="1" <?= ($this -> delka === 1) ? 'checked="checked"' : '' ?> />
                        <?= TextManager::_('Absence_pulka_smeny1') ?>
                    </label>

                    <label>
                        <input name="delka" type="radio" value="2" <?= ($this -> delka === 2) ? 'checked="checked"' : '' ?> />
                        <?= TextManager::_('Absence_pulka_smeny2') ?>
                    </label>
                </div>
            </div>

            <div class="row margin-top" id="podlekalendare_row_pocatekkonec">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-9">
                    <label>
                        <input name="pocatekkonec" class="app_check" type="checkbox" value="1" <?= $this -> pouzitPocatek ? 'checked="checked"' : '' ?> />
                        <span class="<?= $this -> pouzitPocatek ? 'checkbox_text_checked' : 'checkbox_text_unchecked' ?>"><?= TextManager::_('Pouzit_pocatek_konec_smeny') ?></span>
                    </label>
                </div>
            </div>

            <div class="row" id="podlekalendare_row_pevnejadro">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-9">
                    <label>
                        <input name="pevnejadro" class="app_check" type="checkbox" value="1" <?= $this -> pevneJadro ? 'checked="checked"' : '' ?> />
                        <span class="<?= $this -> pevneJadro ? 'checkbox_text_checked' : 'checkbox_text_unchecked' ?>"><?= TextManager::_('Pouzit_pevne_jadro') ?></span>
                    </label>
                </div>
            </div>

            <div class="row" id="podlekalendare_row_autoopakovat">
                <div class="col col-3 d-xs-none"></div>
                <div class="col col-12 col-sm-9">
                    <label>
                        <input name="autoopakovat" class="app_check" type="checkbox" value="1" <?= $this -> automatickyOpakovat ? 'checked="checked"' : '' ?> />
                        <span class="<?= $this -> automatickyOpakovat ? 'checkbox_text_checked' : 'checkbox_text_unchecked' ?>"><?= TextManager::_('Automaticky_opakovat') ?></span>
                    </label>
                </div>
            </div>

            <?php if ( !RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_VKLADAT_PRESTAVKY) ) { ?>
                <div class="row" id="podlekalendare_row_vlozitprestavky">
                    <div class="col col-3 d-xs-none"></div>
                    <div class="col col-12 col-sm-9">
                        <label>
                            <input name="vlozitprestavky" class="app_check" type="checkbox" value="1" <?= $this -> vlozitPrestavky ? 'checked="checked"' : '' ?> />
                            <span class="<?= $this -> vlozitPrestavky ? 'checkbox_text_checked' : 'checkbox_text_unchecked' ?>"><?= TextManager::_('Vlozit_prestavky') ?></span>
                        </label>
                    </div>
                </div>
            <?php } ?>
        </div>

        <div class="buttons row">
            <div class="col col-3">
                <span><a href="?menuid=zpracovanadochazka&osoba=<?= $this ->pp ->idPP ?>&obdobi=<?= DateUtils::dateToUrlString($this ->obdobi ->zacatek) ?>"><?= TextManager::_('Zpet') ?></a></span>
            </div>
            <div class="col col-9">
                <input type="submit" class="submitbutton" name="podlepuvodni" value="<?= TextManager::_('form.Insert') ?>" />
            </div>

        </div>
    </div>
</form>
